/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. See
 * http://www.eu-egee.org/partners/ for details on the copyright holders.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

import org.apache.log4j.Logger;

import org.glite.security.delegation.GrDPX509Util;
import org.glite.security.delegation.impl.GliteDelegation;
import org.glite.security.delegation.DelegationHandler;
import org.glite.security.delegation.impl.GliteDelegation;

import java.net.URL;

import java.util.Random;


/*
 * Sample code for client side of Java delegation
 */
public class DelegationClient {
    public static void main(String[] args) throws Exception {
        Logger logger = Logger.getLogger(DelegationClient.class);
        String location = args[1];
        String delegationID = args[0];


        //To be ensure for generating random delegationIDs we overwrite your value

        Random generator = new Random();
        int rnd = generator.nextInt(65000);
        delegationID = Integer.toString(rnd);

        logger.debug("Service Location is : " + location)
        logger.debug("Generated random delegation ID is : " + delegationID);

        URL endPoint = new URL(args[1]);

        org.glite.security.delegation.service.DelegationService service = new org.glite.security.delegation.service.DelegationServiceLocator();
        org.glite.security.delegation.service.Delegation dlg = service.getDelegation(endPoint);

        String pkc10ReqCert = null;

        //Requesting a certificate request
        pkc10ReqCert = dlg.getProxyReq(delegationID);

        if (pkc10ReqCert != null) {
            logger.debug("Certificate Request \n" + pkc10ReqCert);
            
            DelegationHandler dlgHandler = new DelegationHandler(pkc10ReqCert,
                    delegationID, GrDPX509Util.getDlgorPropertyFile());

            dlg.putProxy(delegationID, dlgHandler.getPEMProxyCertificate());
        } else {
            GrDPX509Util.errorResponse("50 Server internal Error");
            logger.error("Error, Service refused or other error happend to perfoem delegation");
            System.exit(0);
        }

    }
}
