/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. See
 * http://www.eu-egee.org/partners/ for details on the copyright holders.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.glite.security.delegation.service;

import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

public class DelegationContextListener implements ServletContextListener {
	static private boolean wasCalled = false;

    /* Log4j logger for class */
    private final static Logger m_log = Logger.getLogger(DelegationContextListener.class);

    public void contextInitialized(ServletContextEvent event) {
        // Load the alternative log4j config file
        configureLogger(event.getServletContext());

    }

    public void contextDestroyed(ServletContextEvent event) {
        // Load the alternative log4j config file
        configureLogger(event.getServletContext());
    }

	public void configureLogger(ServletContext ctx) {

		// Take the value from a config param in context.xml
		String propFileLocation = ctx.getInitParameter("log4j.configFile.path");

		// Make sure it is only called once
		if(!wasCalled) {
			
			// Load the new configuration and set the watch if a location was given
		    if(propFileLocation != null) {
		    	PropertyConfigurator.configureAndWatch(propFileLocation, 60000);
		    	m_log.info("Alternative log4j properties file location: " + propFileLocation);
		    } else {
		    	m_log.info("No alternative log4j properties file location given. Will try classpath.");
		    }
		    
			wasCalled = true;
		}
	
	}
}
